@@ -39,10 +39,10 @@ class Menu_Manager(object):
     class principale de pygame qui gère la fenetre
     """
     @overload
-    def setup(self,name=None,size:Vector2=None,background=None,icon=None) -> None: ...
+    def __init__(self,name=None,size:Vector2=None,background=None,icon=None) -> None: ...
     @overload
-    def setup(self,window:py.Surface=None,background=None) -> None: ...
-    def setup(self,window:py.Surface=None,name=None,size:Vector2=None,background=None,icon=None) -> None:
+    def __init__(self,window:py.Surface=None,background=None) -> None: ...
+    def __init__(self,window:py.Surface=None,name=None,size:Vector2=None,background=None,icon=None) -> None:
         """
         initialisation de pygame et de la fenêtre et des variables globales
 
